# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/upgrade.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from grafeas.grafeas_v1.proto import (
    package_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/upgrade.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n&grafeas/grafeas_v1/proto/upgrade.proto\x12\ngrafeas.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&grafeas/grafeas_v1/proto/package.proto"\xaf\x01\n\x0bUpgradeNote\x12\x0f\n\x07package\x18\x01 \x01(\t\x12$\n\x07version\x18\x02 \x01(\x0b\x32\x13.grafeas.v1.Version\x12\x36\n\rdistributions\x18\x03 \x03(\x0b\x32\x1f.grafeas.v1.UpgradeDistribution\x12\x31\n\x0ewindows_update\x18\x04 \x01(\x0b\x32\x19.grafeas.v1.WindowsUpdate"]\n\x13UpgradeDistribution\x12\x0f\n\x07\x63pe_uri\x18\x01 \x01(\t\x12\x16\n\x0e\x63lassification\x18\x02 \x01(\t\x12\x10\n\x08severity\x18\x03 \x01(\t\x12\x0b\n\x03\x63ve\x18\x04 \x03(\t"\xec\x02\n\rWindowsUpdate\x12\x34\n\x08identity\x18\x01 \x01(\x0b\x32".grafeas.v1.WindowsUpdate.Identity\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x36\n\ncategories\x18\x04 \x03(\x0b\x32".grafeas.v1.WindowsUpdate.Category\x12\x16\n\x0ekb_article_ids\x18\x05 \x03(\t\x12\x13\n\x0bsupport_url\x18\x06 \x01(\t\x12<\n\x18last_published_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a/\n\x08Identity\x12\x11\n\tupdate_id\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\x05\x1a-\n\x08\x43\x61tegory\x12\x13\n\x0b\x63\x61tegory_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"\xbb\x01\n\x11UpgradeOccurrence\x12\x0f\n\x07package\x18\x01 \x01(\t\x12+\n\x0eparsed_version\x18\x03 \x01(\x0b\x32\x13.grafeas.v1.Version\x12\x35\n\x0c\x64istribution\x18\x04 \x01(\x0b\x32\x1f.grafeas.v1.UpgradeDistribution\x12\x31\n\x0ewindows_update\x18\x05 \x01(\x0b\x32\x19.grafeas.v1.WindowsUpdateB_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2.DESCRIPTOR,
    ],
)


_UPGRADENOTE = _descriptor.Descriptor(
    name="UpgradeNote",
    full_name="grafeas.v1.UpgradeNote",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="package",
            full_name="grafeas.v1.UpgradeNote.package",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="grafeas.v1.UpgradeNote.version",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distributions",
            full_name="grafeas.v1.UpgradeNote.distributions",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="windows_update",
            full_name="grafeas.v1.UpgradeNote.windows_update",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=128,
    serialized_end=303,
)


_UPGRADEDISTRIBUTION = _descriptor.Descriptor(
    name="UpgradeDistribution",
    full_name="grafeas.v1.UpgradeDistribution",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="cpe_uri",
            full_name="grafeas.v1.UpgradeDistribution.cpe_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="classification",
            full_name="grafeas.v1.UpgradeDistribution.classification",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="severity",
            full_name="grafeas.v1.UpgradeDistribution.severity",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cve",
            full_name="grafeas.v1.UpgradeDistribution.cve",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=305,
    serialized_end=398,
)


_WINDOWSUPDATE_IDENTITY = _descriptor.Descriptor(
    name="Identity",
    full_name="grafeas.v1.WindowsUpdate.Identity",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="update_id",
            full_name="grafeas.v1.WindowsUpdate.Identity.update_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="revision",
            full_name="grafeas.v1.WindowsUpdate.Identity.revision",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=671,
    serialized_end=718,
)

_WINDOWSUPDATE_CATEGORY = _descriptor.Descriptor(
    name="Category",
    full_name="grafeas.v1.WindowsUpdate.Category",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="category_id",
            full_name="grafeas.v1.WindowsUpdate.Category.category_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.WindowsUpdate.Category.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=720,
    serialized_end=765,
)

_WINDOWSUPDATE = _descriptor.Descriptor(
    name="WindowsUpdate",
    full_name="grafeas.v1.WindowsUpdate",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="identity",
            full_name="grafeas.v1.WindowsUpdate.identity",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="title",
            full_name="grafeas.v1.WindowsUpdate.title",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="grafeas.v1.WindowsUpdate.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="categories",
            full_name="grafeas.v1.WindowsUpdate.categories",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kb_article_ids",
            full_name="grafeas.v1.WindowsUpdate.kb_article_ids",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="support_url",
            full_name="grafeas.v1.WindowsUpdate.support_url",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="last_published_timestamp",
            full_name="grafeas.v1.WindowsUpdate.last_published_timestamp",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_WINDOWSUPDATE_IDENTITY, _WINDOWSUPDATE_CATEGORY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=401,
    serialized_end=765,
)


_UPGRADEOCCURRENCE = _descriptor.Descriptor(
    name="UpgradeOccurrence",
    full_name="grafeas.v1.UpgradeOccurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="package",
            full_name="grafeas.v1.UpgradeOccurrence.package",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="parsed_version",
            full_name="grafeas.v1.UpgradeOccurrence.parsed_version",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distribution",
            full_name="grafeas.v1.UpgradeOccurrence.distribution",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="windows_update",
            full_name="grafeas.v1.UpgradeOccurrence.windows_update",
            index=3,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=768,
    serialized_end=955,
)

_UPGRADENOTE.fields_by_name[
    "version"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2._VERSION
_UPGRADENOTE.fields_by_name["distributions"].message_type = _UPGRADEDISTRIBUTION
_UPGRADENOTE.fields_by_name["windows_update"].message_type = _WINDOWSUPDATE
_WINDOWSUPDATE_IDENTITY.containing_type = _WINDOWSUPDATE
_WINDOWSUPDATE_CATEGORY.containing_type = _WINDOWSUPDATE
_WINDOWSUPDATE.fields_by_name["identity"].message_type = _WINDOWSUPDATE_IDENTITY
_WINDOWSUPDATE.fields_by_name["categories"].message_type = _WINDOWSUPDATE_CATEGORY
_WINDOWSUPDATE.fields_by_name[
    "last_published_timestamp"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_UPGRADEOCCURRENCE.fields_by_name[
    "parsed_version"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2._VERSION
_UPGRADEOCCURRENCE.fields_by_name["distribution"].message_type = _UPGRADEDISTRIBUTION
_UPGRADEOCCURRENCE.fields_by_name["windows_update"].message_type = _WINDOWSUPDATE
DESCRIPTOR.message_types_by_name["UpgradeNote"] = _UPGRADENOTE
DESCRIPTOR.message_types_by_name["UpgradeDistribution"] = _UPGRADEDISTRIBUTION
DESCRIPTOR.message_types_by_name["WindowsUpdate"] = _WINDOWSUPDATE
DESCRIPTOR.message_types_by_name["UpgradeOccurrence"] = _UPGRADEOCCURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UpgradeNote = _reflection.GeneratedProtocolMessageType(
    "UpgradeNote",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPGRADENOTE,
        "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
        "__doc__": """An Upgrade Note represents a potential upgrade of a package to a given
  version. For each package version combination (i.e. bash 4.0, bash
  4.1, bash 4.1.2), there will be an Upgrade Note. For Windows,
  windows_update field represents the information related to the update.
  
  Attributes:
      package:
          Required for non-Windows OS. The package this Upgrade is for.
      version:
          Required for non-Windows OS. The version of the package in
          machine + human readable form.
      distributions:
          Metadata about the upgrade for each specific operating system.
      windows_update:
          Required for Windows OS. Represents the metadata about the
          Windows update.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.UpgradeNote)
    },
)
_sym_db.RegisterMessage(UpgradeNote)

UpgradeDistribution = _reflection.GeneratedProtocolMessageType(
    "UpgradeDistribution",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPGRADEDISTRIBUTION,
        "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
        "__doc__": """The Upgrade Distribution represents metadata about the Upgrade for
  each operating system (CPE). Some distributions have additional
  metadata around updates, classifying them into various categories and
  severities.
  
  Attributes:
      cpe_uri:
          Required - The specific operating system this metadata applies
          to. See https://cpe.mitre.org/specification/.
      classification:
          The operating system classification of this Upgrade, as
          specified by the upstream operating system upgrade feed. For
          Windows the classification is one of the category_ids listed
          at https://docs.microsoft.com/en-us/previous-
          versions/windows/desktop/ff357803(v=vs.85)
      severity:
          The severity as specified by the upstream operating system.
      cve:
          The cve tied to this Upgrade.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.UpgradeDistribution)
    },
)
_sym_db.RegisterMessage(UpgradeDistribution)

WindowsUpdate = _reflection.GeneratedProtocolMessageType(
    "WindowsUpdate",
    (_message.Message,),
    {
        "Identity": _reflection.GeneratedProtocolMessageType(
            "Identity",
            (_message.Message,),
            {
                "DESCRIPTOR": _WINDOWSUPDATE_IDENTITY,
                "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
                "__doc__": """The unique identifier of the update.
    
    Attributes:
        update_id:
            The revision independent identifier of the update.
        revision:
            The revision number of the update.
    """,
                # @@protoc_insertion_point(class_scope:grafeas.v1.WindowsUpdate.Identity)
            },
        ),
        "Category": _reflection.GeneratedProtocolMessageType(
            "Category",
            (_message.Message,),
            {
                "DESCRIPTOR": _WINDOWSUPDATE_CATEGORY,
                "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
                "__doc__": """The category to which the update belongs.
    
    Attributes:
        category_id:
            The identifier of the category.
        name:
            The localized name of the category.
    """,
                # @@protoc_insertion_point(class_scope:grafeas.v1.WindowsUpdate.Category)
            },
        ),
        "DESCRIPTOR": _WINDOWSUPDATE,
        "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
        "__doc__": """Windows Update represents the metadata about the update for the
  Windows operating system. The fields in this message come from the
  Windows Update API documented at https://docs.microsoft.com/en-
  us/windows/win32/api/wuapi/nn-wuapi-iupdate.
  
  Attributes:
      identity:
          Required - The unique identifier for the update.
      title:
          The localized title of the update.
      description:
          The localized description of the update.
      categories:
          The list of categories to which the update belongs.
      kb_article_ids:
          The Microsoft Knowledge Base article IDs that are associated
          with the update.
      support_url:
          The hyperlink to the support information for the update.
      last_published_timestamp:
          The last published timestamp of the update.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.WindowsUpdate)
    },
)
_sym_db.RegisterMessage(WindowsUpdate)
_sym_db.RegisterMessage(WindowsUpdate.Identity)
_sym_db.RegisterMessage(WindowsUpdate.Category)

UpgradeOccurrence = _reflection.GeneratedProtocolMessageType(
    "UpgradeOccurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPGRADEOCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.upgrade_pb2",
        "__doc__": """An Upgrade Occurrence represents that a specific resource_url could
  install a specific upgrade. This presence is supplied via local
  sources (i.e. it is present in the mirror and the running system has
  noticed its availability). For Windows, both distribution and
  windows_update contain information for the Windows update.
  
  Attributes:
      package:
          Required for non-Windows OS. The package this Upgrade is for.
      parsed_version:
          Required for non-Windows OS. The version of the package in a
          machine + human readable form.
      distribution:
          Metadata about the upgrade for available for the specific
          operating system for the resource_url. This allows efficient
          filtering, as well as making it easier to use the occurrence.
      windows_update:
          Required for Windows OS. Represents the metadata about the
          Windows update.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.UpgradeOccurrence)
    },
)
_sym_db.RegisterMessage(UpgradeOccurrence)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



config = {
    "interfaces": {
        "grafeas.v1.Grafeas": {
            "retry_codes": {
                "retry_policy_1_codes": ["UNAVAILABLE", "DEADLINE_EXCEEDED"],
                "no_retry_codes": [],
                "no_retry_1_codes": [],
            },
            "retry_params": {
                "retry_policy_1_params": {
                    "initial_retry_delay_millis": 100,
                    "retry_delay_multiplier": 1.3,
                    "max_retry_delay_millis": 60000,
                    "initial_rpc_timeout_millis": 30000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 30000,
                    "total_timeout_millis": 30000,
                },
                "no_retry_params": {
                    "initial_retry_delay_millis": 0,
                    "retry_delay_multiplier": 0.0,
                    "max_retry_delay_millis": 0,
                    "initial_rpc_timeout_millis": 0,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 0,
                    "total_timeout_millis": 0,
                },
                "no_retry_1_params": {
                    "initial_retry_delay_millis": 0,
                    "retry_delay_multiplier": 0.0,
                    "max_retry_delay_millis": 0,
                    "initial_rpc_timeout_millis": 30000,
                    "rpc_timeout_multiplier": 1.0,
                    "max_rpc_timeout_millis": 30000,
                    "total_timeout_millis": 30000,
                },
            },
            "methods": {
                "GetOccurrence": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "ListOccurrences": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "DeleteOccurrence": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "CreateOccurrence": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "BatchCreateOccurrences": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "UpdateOccurrence": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "GetOccurrenceNote": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "GetNote": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "ListNotes": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "DeleteNote": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
                "CreateNote": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "BatchCreateNotes": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "UpdateNote": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "no_retry_1_codes",
                    "retry_params_name": "no_retry_1_params",
                },
                "ListNoteOccurrences": {
                    "timeout_millis": 30000,
                    "retry_codes_name": "retry_policy_1_codes",
                    "retry_params_name": "retry_policy_1_params",
                },
            },
        }
    }
}



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Wrappers for protocol buffer enum types."""

import enum


class Architecture(enum.IntEnum):
    """
    Instruction set architectures supported by various package managers.

    Attributes:
      ARCHITECTURE_UNSPECIFIED (int): Unknown architecture.
      X86 (int): X86 architecture.
      X64 (int): X64 architecture.
    """

    ARCHITECTURE_UNSPECIFIED = 0
    X86 = 1
    X64 = 2


class NoteKind(enum.IntEnum):
    """
    Kind represents the kinds of notes supported.

    Attributes:
      NOTE_KIND_UNSPECIFIED (int): Unknown.
      VULNERABILITY (int): The note and occurrence represent a package vulnerability.
      BUILD (int): The note and occurrence assert build provenance.
      IMAGE (int): This represents an image basis relationship.
      PACKAGE (int): This represents a package installed via a package manager.
      DEPLOYMENT (int): The note and occurrence track deployment events.
      DISCOVERY (int): The note and occurrence track the initial discovery status of a resource.
      ATTESTATION (int): This represents a logical "role" that can attest to artifacts.
      UPGRADE (int): This represents an available package upgrade.
    """

    NOTE_KIND_UNSPECIFIED = 0
    VULNERABILITY = 1
    BUILD = 2
    IMAGE = 3
    PACKAGE = 4
    DEPLOYMENT = 5
    DISCOVERY = 6
    ATTESTATION = 7
    UPGRADE = 8


class Severity(enum.IntEnum):
    """
    Note provider assigned severity/impact ranking.

    Attributes:
      SEVERITY_UNSPECIFIED (int): Unknown.
      MINIMAL (int): Minimal severity.
      LOW (int): Low severity.
      MEDIUM (int): Medium severity.
      HIGH (int): High severity.
      CRITICAL (int): Critical severity.
    """

    SEVERITY_UNSPECIFIED = 0
    MINIMAL = 1
    LOW = 2
    MEDIUM = 3
    HIGH = 4
    CRITICAL = 5


class AliasContext(object):
    class Kind(enum.IntEnum):
        """
        The type of an alias.

        Attributes:
          KIND_UNSPECIFIED (int): Unknown.
          FIXED (int): Git tag.
          MOVABLE (int): Git branch.
          OTHER (int): Used to specify non-standard aliases. For example, if a Git repo has a
          ref named "refs/foo/bar".
        """

        KIND_UNSPECIFIED = 0
        FIXED = 1
        MOVABLE = 2
        OTHER = 4


class CVSSv3(object):
    class AttackComplexity(enum.IntEnum):
        """
        Attributes:
          ATTACK_COMPLEXITY_UNSPECIFIED (int)
          ATTACK_COMPLEXITY_LOW (int)
          ATTACK_COMPLEXITY_HIGH (int)
        """

        ATTACK_COMPLEXITY_UNSPECIFIED = 0
        ATTACK_COMPLEXITY_LOW = 1
        ATTACK_COMPLEXITY_HIGH = 2

    class AttackVector(enum.IntEnum):
        """
        Attributes:
          ATTACK_VECTOR_UNSPECIFIED (int)
          ATTACK_VECTOR_NETWORK (int)
          ATTACK_VECTOR_ADJACENT (int)
          ATTACK_VECTOR_LOCAL (int)
          ATTACK_VECTOR_PHYSICAL (int)
        """

        ATTACK_VECTOR_UNSPECIFIED = 0
        ATTACK_VECTOR_NETWORK = 1
        ATTACK_VECTOR_ADJACENT = 2
        ATTACK_VECTOR_LOCAL = 3
        ATTACK_VECTOR_PHYSICAL = 4

    class Impact(enum.IntEnum):
        """
        Attributes:
          IMPACT_UNSPECIFIED (int)
          IMPACT_HIGH (int)
          IMPACT_LOW (int)
          IMPACT_NONE (int)
        """

        IMPACT_UNSPECIFIED = 0
        IMPACT_HIGH = 1
        IMPACT_LOW = 2
        IMPACT_NONE = 3

    class PrivilegesRequired(enum.IntEnum):
        """
        Attributes:
          PRIVILEGES_REQUIRED_UNSPECIFIED (int)
          PRIVILEGES_REQUIRED_NONE (int)
          PRIVILEGES_REQUIRED_LOW (int)
          PRIVILEGES_REQUIRED_HIGH (int)
        """

        PRIVILEGES_REQUIRED_UNSPECIFIED = 0
        PRIVILEGES_REQUIRED_NONE = 1
        PRIVILEGES_REQUIRED_LOW = 2
        PRIVILEGES_REQUIRED_HIGH = 3

    class Scope(enum.IntEnum):
        """
        Attributes:
          SCOPE_UNSPECIFIED (int)
          SCOPE_UNCHANGED (int)
          SCOPE_CHANGED (int)
        """

        SCOPE_UNSPECIFIED = 0
        SCOPE_UNCHANGED = 1
        SCOPE_CHANGED = 2

    class UserInteraction(enum.IntEnum):
        """
        Attributes:
          USER_INTERACTION_UNSPECIFIED (int)
          USER_INTERACTION_NONE (int)
          USER_INTERACTION_REQUIRED (int)
        """

        USER_INTERACTION_UNSPECIFIED = 0
        USER_INTERACTION_NONE = 1
        USER_INTERACTION_REQUIRED = 2


class DeploymentOccurrence(object):
    class Platform(enum.IntEnum):
        """
        Types of platforms.

        Attributes:
          PLATFORM_UNSPECIFIED (int): Unknown.
          GKE (int): Google Container Engine.
          FLEX (int): Google App Engine: Flexible Environment.
          CUSTOM (int): Custom user-defined platform.
        """

        PLATFORM_UNSPECIFIED = 0
        GKE = 1
        FLEX = 2
        CUSTOM = 3


class DiscoveryOccurrence(object):
    class AnalysisStatus(enum.IntEnum):
        """
        Analysis status for a resource. Currently for initial analysis only (not
        updated in continuous analysis).

        Attributes:
          ANALYSIS_STATUS_UNSPECIFIED (int): Unknown.
          PENDING (int): Resource is known but no action has been taken yet.
          SCANNING (int): Resource is being analyzed.
          FINISHED_SUCCESS (int): Analysis has finished successfully.
          FINISHED_FAILED (int): Analysis has finished unsuccessfully, the analysis itself is in a bad
          state.
          FINISHED_UNSUPPORTED (int): The resource is known not to be supported
        """

        ANALYSIS_STATUS_UNSPECIFIED = 0
        PENDING = 1
        SCANNING = 2
        FINISHED_SUCCESS = 3
        FINISHED_FAILED = 4
        FINISHED_UNSUPPORTED = 5

    class ContinuousAnalysis(enum.IntEnum):
        """
        Whether the resource is continuously analyzed.

        Attributes:
          CONTINUOUS_ANALYSIS_UNSPECIFIED (int): Unknown.
          ACTIVE (int): The resource is continuously analyzed.
          INACTIVE (int): The resource is ignored for continuous analysis.
        """

        CONTINUOUS_ANALYSIS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


class Version(object):
    class VersionKind(enum.IntEnum):
        """
        Whether this is an ordinary package version or a sentinel MIN/MAX version.

        Attributes:
          VERSION_KIND_UNSPECIFIED (int): Unknown.
          NORMAL (int): A standard package version.
          MINIMUM (int): A special version representing negative infinity.
          MAXIMUM (int): A special version representing positive infinity.
        """

        VERSION_KIND_UNSPECIFIED = 0
        NORMAL = 1
        MINIMUM = 2
        MAXIMUM = 3



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/discovery.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from grafeas.grafeas_v1.proto import (
    common_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/discovery.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n(grafeas/grafeas_v1/proto/discovery.proto\x12\ngrafeas.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a%grafeas/grafeas_v1/proto/common.proto"<\n\rDiscoveryNote\x12+\n\ranalysis_kind\x18\x01 \x01(\x0e\x32\x14.grafeas.v1.NoteKind"\x8c\x04\n\x13\x44iscoveryOccurrence\x12O\n\x13\x63ontinuous_analysis\x18\x01 \x01(\x0e\x32\x32.grafeas.v1.DiscoveryOccurrence.ContinuousAnalysis\x12G\n\x0f\x61nalysis_status\x18\x02 \x01(\x0e\x32..grafeas.v1.DiscoveryOccurrence.AnalysisStatus\x12\x31\n\x15\x61nalysis_status_error\x18\x03 \x01(\x0b\x32\x12.google.rpc.Status\x12\x0b\n\x03\x63pe\x18\x04 \x01(\t\x12\x32\n\x0elast_scan_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"S\n\x12\x43ontinuousAnalysis\x12#\n\x1f\x43ONTINUOUS_ANALYSIS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02"\x91\x01\n\x0e\x41nalysisStatus\x12\x1f\n\x1b\x41NALYSIS_STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08SCANNING\x10\x02\x12\x14\n\x10\x46INISHED_SUCCESS\x10\x03\x12\x13\n\x0f\x46INISHED_FAILED\x10\x04\x12\x18\n\x14\x46INISHED_UNSUPPORTED\x10\x05\x42_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
    dependencies=[
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2.DESCRIPTOR,
    ],
)


_DISCOVERYOCCURRENCE_CONTINUOUSANALYSIS = _descriptor.EnumDescriptor(
    name="ContinuousAnalysis",
    full_name="grafeas.v1.DiscoveryOccurrence.ContinuousAnalysis",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="CONTINUOUS_ANALYSIS_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ACTIVE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INACTIVE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=509,
    serialized_end=592,
)
_sym_db.RegisterEnumDescriptor(_DISCOVERYOCCURRENCE_CONTINUOUSANALYSIS)

_DISCOVERYOCCURRENCE_ANALYSISSTATUS = _descriptor.EnumDescriptor(
    name="AnalysisStatus",
    full_name="grafeas.v1.DiscoveryOccurrence.AnalysisStatus",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ANALYSIS_STATUS_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PENDING",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SCANNING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FINISHED_SUCCESS",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FINISHED_FAILED",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FINISHED_UNSUPPORTED",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=595,
    serialized_end=740,
)
_sym_db.RegisterEnumDescriptor(_DISCOVERYOCCURRENCE_ANALYSISSTATUS)


_DISCOVERYNOTE = _descriptor.Descriptor(
    name="DiscoveryNote",
    full_name="grafeas.v1.DiscoveryNote",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="analysis_kind",
            full_name="grafeas.v1.DiscoveryNote.analysis_kind",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=153,
    serialized_end=213,
)


_DISCOVERYOCCURRENCE = _descriptor.Descriptor(
    name="DiscoveryOccurrence",
    full_name="grafeas.v1.DiscoveryOccurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="continuous_analysis",
            full_name="grafeas.v1.DiscoveryOccurrence.continuous_analysis",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_status",
            full_name="grafeas.v1.DiscoveryOccurrence.analysis_status",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="analysis_status_error",
            full_name="grafeas.v1.DiscoveryOccurrence.analysis_status_error",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="cpe",
            full_name="grafeas.v1.DiscoveryOccurrence.cpe",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="last_scan_time",
            full_name="grafeas.v1.DiscoveryOccurrence.last_scan_time",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _DISCOVERYOCCURRENCE_CONTINUOUSANALYSIS,
        _DISCOVERYOCCURRENCE_ANALYSISSTATUS,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=216,
    serialized_end=740,
)

_DISCOVERYNOTE.fields_by_name[
    "analysis_kind"
].enum_type = grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2._NOTEKIND
_DISCOVERYOCCURRENCE.fields_by_name[
    "continuous_analysis"
].enum_type = _DISCOVERYOCCURRENCE_CONTINUOUSANALYSIS
_DISCOVERYOCCURRENCE.fields_by_name[
    "analysis_status"
].enum_type = _DISCOVERYOCCURRENCE_ANALYSISSTATUS
_DISCOVERYOCCURRENCE.fields_by_name[
    "analysis_status_error"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_DISCOVERYOCCURRENCE.fields_by_name[
    "last_scan_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_DISCOVERYOCCURRENCE_CONTINUOUSANALYSIS.containing_type = _DISCOVERYOCCURRENCE
_DISCOVERYOCCURRENCE_ANALYSISSTATUS.containing_type = _DISCOVERYOCCURRENCE
DESCRIPTOR.message_types_by_name["DiscoveryNote"] = _DISCOVERYNOTE
DESCRIPTOR.message_types_by_name["DiscoveryOccurrence"] = _DISCOVERYOCCURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DiscoveryNote = _reflection.GeneratedProtocolMessageType(
    "DiscoveryNote",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISCOVERYNOTE,
        "__module__": "grafeas.grafeas_v1.proto.discovery_pb2",
        "__doc__": """A note that indicates a type of analysis a provider would perform.
  This note exists in a provider’s project. A ``Discovery`` occurrence
  is created in a consumer’s project at the start of analysis.
  
  Attributes:
      analysis_kind:
          Required. Immutable. The kind of analysis that is handled by
          this discovery.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.DiscoveryNote)
    },
)
_sym_db.RegisterMessage(DiscoveryNote)

DiscoveryOccurrence = _reflection.GeneratedProtocolMessageType(
    "DiscoveryOccurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISCOVERYOCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.discovery_pb2",
        "__doc__": """Provides information about the analysis status of a discovered
  resource.
  
  Attributes:
      continuous_analysis:
          Whether the resource is continuously analyzed.
      analysis_status:
          The status of discovery for the resource.
      analysis_status_error:
          When an error is encountered this will contain a
          LocalizedMessage under details to show to the user. The
          LocalizedMessage is output only and populated by the API.
      cpe:
          The CPE of the resource being scanned.
      last_scan_time:
          The last time this resource was scanned.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.DiscoveryOccurrence)
    },
)
_sym_db.RegisterMessage(DiscoveryOccurrence)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/package.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/package.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n&grafeas/grafeas_v1/proto/package.proto\x12\ngrafeas.v1"\xb2\x01\n\x0c\x44istribution\x12\x0f\n\x07\x63pe_uri\x18\x01 \x01(\t\x12.\n\x0c\x61rchitecture\x18\x02 \x01(\x0e\x32\x18.grafeas.v1.Architecture\x12+\n\x0elatest_version\x18\x03 \x01(\x0b\x32\x13.grafeas.v1.Version\x12\x12\n\nmaintainer\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t"O\n\x08Location\x12\x0f\n\x07\x63pe_uri\x18\x01 \x01(\t\x12$\n\x07version\x18\x02 \x01(\x0b\x32\x13.grafeas.v1.Version\x12\x0c\n\x04path\x18\x03 \x01(\t"K\n\x0bPackageNote\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x0c\x64istribution\x18\n \x03(\x0b\x32\x18.grafeas.v1.Distribution"I\n\x11PackageOccurrence\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x08location\x18\x02 \x03(\x0b\x32\x14.grafeas.v1.Location"\xcd\x01\n\x07Version\x12\r\n\x05\x65poch\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12-\n\x04kind\x18\x04 \x01(\x0e\x32\x1f.grafeas.v1.Version.VersionKind\x12\x11\n\tfull_name\x18\x05 \x01(\t"Q\n\x0bVersionKind\x12\x1c\n\x18VERSION_KIND_UNSPECIFIED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x0b\n\x07MINIMUM\x10\x02\x12\x0b\n\x07MAXIMUM\x10\x03*>\n\x0c\x41rchitecture\x12\x1c\n\x18\x41RCHITECTURE_UNSPECIFIED\x10\x00\x12\x07\n\x03X86\x10\x01\x12\x07\n\x03X64\x10\x02\x42_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
)

_ARCHITECTURE = _descriptor.EnumDescriptor(
    name="Architecture",
    full_name="grafeas.v1.Architecture",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ARCHITECTURE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="X86",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="X64",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=676,
    serialized_end=738,
)
_sym_db.RegisterEnumDescriptor(_ARCHITECTURE)

Architecture = enum_type_wrapper.EnumTypeWrapper(_ARCHITECTURE)
ARCHITECTURE_UNSPECIFIED = 0
X86 = 1
X64 = 2


_VERSION_VERSIONKIND = _descriptor.EnumDescriptor(
    name="VersionKind",
    full_name="grafeas.v1.Version.VersionKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="VERSION_KIND_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="NORMAL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MINIMUM",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MAXIMUM",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=593,
    serialized_end=674,
)
_sym_db.RegisterEnumDescriptor(_VERSION_VERSIONKIND)


_DISTRIBUTION = _descriptor.Descriptor(
    name="Distribution",
    full_name="grafeas.v1.Distribution",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="cpe_uri",
            full_name="grafeas.v1.Distribution.cpe_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="architecture",
            full_name="grafeas.v1.Distribution.architecture",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="latest_version",
            full_name="grafeas.v1.Distribution.latest_version",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="maintainer",
            full_name="grafeas.v1.Distribution.maintainer",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="url",
            full_name="grafeas.v1.Distribution.url",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="grafeas.v1.Distribution.description",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=55,
    serialized_end=233,
)


_LOCATION = _descriptor.Descriptor(
    name="Location",
    full_name="grafeas.v1.Location",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="cpe_uri",
            full_name="grafeas.v1.Location.cpe_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="version",
            full_name="grafeas.v1.Location.version",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="path",
            full_name="grafeas.v1.Location.path",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=235,
    serialized_end=314,
)


_PACKAGENOTE = _descriptor.Descriptor(
    name="PackageNote",
    full_name="grafeas.v1.PackageNote",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.PackageNote.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distribution",
            full_name="grafeas.v1.PackageNote.distribution",
            index=1,
            number=10,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=316,
    serialized_end=391,
)


_PACKAGEOCCURRENCE = _descriptor.Descriptor(
    name="PackageOccurrence",
    full_name="grafeas.v1.PackageOccurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.PackageOccurrence.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="location",
            full_name="grafeas.v1.PackageOccurrence.location",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=393,
    serialized_end=466,
)


_VERSION = _descriptor.Descriptor(
    name="Version",
    full_name="grafeas.v1.Version",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="epoch",
            full_name="grafeas.v1.Version.epoch",
            index=0,
            number=1,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.Version.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="revision",
            full_name="grafeas.v1.Version.revision",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="grafeas.v1.Version.kind",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="full_name",
            full_name="grafeas.v1.Version.full_name",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_VERSION_VERSIONKIND,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=469,
    serialized_end=674,
)

_DISTRIBUTION.fields_by_name["architecture"].enum_type = _ARCHITECTURE
_DISTRIBUTION.fields_by_name["latest_version"].message_type = _VERSION
_LOCATION.fields_by_name["version"].message_type = _VERSION
_PACKAGENOTE.fields_by_name["distribution"].message_type = _DISTRIBUTION
_PACKAGEOCCURRENCE.fields_by_name["location"].message_type = _LOCATION
_VERSION.fields_by_name["kind"].enum_type = _VERSION_VERSIONKIND
_VERSION_VERSIONKIND.containing_type = _VERSION
DESCRIPTOR.message_types_by_name["Distribution"] = _DISTRIBUTION
DESCRIPTOR.message_types_by_name["Location"] = _LOCATION
DESCRIPTOR.message_types_by_name["PackageNote"] = _PACKAGENOTE
DESCRIPTOR.message_types_by_name["PackageOccurrence"] = _PACKAGEOCCURRENCE
DESCRIPTOR.message_types_by_name["Version"] = _VERSION
DESCRIPTOR.enum_types_by_name["Architecture"] = _ARCHITECTURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Distribution = _reflection.GeneratedProtocolMessageType(
    "Distribution",
    (_message.Message,),
    {
        "DESCRIPTOR": _DISTRIBUTION,
        "__module__": "grafeas.grafeas_v1.proto.package_pb2",
        "__doc__": """This represents a particular channel of distribution for a given
  package. E.g., Debian’s jessie-backports dpkg mirror.
  
  Attributes:
      cpe_uri:
          Required. The cpe_uri in `CPE format
          <https://cpe.mitre.org/specification/>`__ denoting the package
          manager version distributing a package.
      architecture:
          The CPU architecture for which packages in this distribution
          channel were built.
      latest_version:
          The latest available version of this package in this
          distribution channel.
      maintainer:
          A freeform string denoting the maintainer of this package.
      url:
          The distribution channel-specific homepage for this package.
      description:
          The distribution channel-specific description of this package.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Distribution)
    },
)
_sym_db.RegisterMessage(Distribution)

Location = _reflection.GeneratedProtocolMessageType(
    "Location",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOCATION,
        "__module__": "grafeas.grafeas_v1.proto.package_pb2",
        "__doc__": """An occurrence of a particular package installation found within a
  system’s filesystem. E.g., glibc was found in
  ``/var/lib/dpkg/status``.
  
  Attributes:
      cpe_uri:
          Required. The CPE URI in `CPE format
          <https://cpe.mitre.org/specification/>`__ denoting the package
          manager version distributing a package.
      version:
          The version installed at this location.
      path:
          The path from which we gathered that this package/version is
          installed.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Location)
    },
)
_sym_db.RegisterMessage(Location)

PackageNote = _reflection.GeneratedProtocolMessageType(
    "PackageNote",
    (_message.Message,),
    {
        "DESCRIPTOR": _PACKAGENOTE,
        "__module__": "grafeas.grafeas_v1.proto.package_pb2",
        "__doc__": """This represents a particular package that is distributed over various
  channels. E.g., glibc (aka libc6) is distributed by many, at various
  versions.
  
  Attributes:
      name:
          Required. Immutable. The name of the package.
      distribution:
          The various channels by which a package is distributed.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.PackageNote)
    },
)
_sym_db.RegisterMessage(PackageNote)

PackageOccurrence = _reflection.GeneratedProtocolMessageType(
    "PackageOccurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _PACKAGEOCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.package_pb2",
        "__doc__": """Details on how a particular software package was installed on a
  system.
  
  Attributes:
      name:
          Output only. The name of the installed package.
      location:
          Required. All of the places within the filesystem versions of
          this package have been found.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.PackageOccurrence)
    },
)
_sym_db.RegisterMessage(PackageOccurrence)

Version = _reflection.GeneratedProtocolMessageType(
    "Version",
    (_message.Message,),
    {
        "DESCRIPTOR": _VERSION,
        "__module__": "grafeas.grafeas_v1.proto.package_pb2",
        "__doc__": """Version contains structured information about the version of a
  package.
  
  Attributes:
      epoch:
          Used to correct mistakes in the version numbering scheme.
      name:
          Required only when version kind is NORMAL. The main part of
          the version name.
      revision:
          The iteration of the package build from the above version.
      kind:
          Required. Distinguishes between sentinel MIN/MAX versions and
          normal versions.
      full_name:
          Human readable version string. This string is of the form :-
          and is only set when kind is NORMAL.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Version)
    },
)
_sym_db.RegisterMessage(Version)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/image.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/image.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n$grafeas/grafeas_v1/proto/image.proto\x12\ngrafeas.v1"-\n\x05Layer\x12\x11\n\tdirective\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x01(\t"@\n\x0b\x46ingerprint\x12\x0f\n\x07v1_name\x18\x01 \x01(\t\x12\x0f\n\x07v2_blob\x18\x02 \x03(\t\x12\x0f\n\x07v2_name\x18\x03 \x01(\t"O\n\tImageNote\x12\x14\n\x0cresource_url\x18\x01 \x01(\t\x12,\n\x0b\x66ingerprint\x18\x02 \x01(\x0b\x32\x17.grafeas.v1.Fingerprint"\x93\x01\n\x0fImageOccurrence\x12,\n\x0b\x66ingerprint\x18\x01 \x01(\x0b\x32\x17.grafeas.v1.Fingerprint\x12\x10\n\x08\x64istance\x18\x02 \x01(\x05\x12%\n\nlayer_info\x18\x03 \x03(\x0b\x32\x11.grafeas.v1.Layer\x12\x19\n\x11\x62\x61se_resource_url\x18\x04 \x01(\tB_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
)


_LAYER = _descriptor.Descriptor(
    name="Layer",
    full_name="grafeas.v1.Layer",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="directive",
            full_name="grafeas.v1.Layer.directive",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="arguments",
            full_name="grafeas.v1.Layer.arguments",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=52,
    serialized_end=97,
)


_FINGERPRINT = _descriptor.Descriptor(
    name="Fingerprint",
    full_name="grafeas.v1.Fingerprint",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="v1_name",
            full_name="grafeas.v1.Fingerprint.v1_name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="v2_blob",
            full_name="grafeas.v1.Fingerprint.v2_blob",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="v2_name",
            full_name="grafeas.v1.Fingerprint.v2_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=99,
    serialized_end=163,
)


_IMAGENOTE = _descriptor.Descriptor(
    name="ImageNote",
    full_name="grafeas.v1.ImageNote",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="resource_url",
            full_name="grafeas.v1.ImageNote.resource_url",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="fingerprint",
            full_name="grafeas.v1.ImageNote.fingerprint",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=165,
    serialized_end=244,
)


_IMAGEOCCURRENCE = _descriptor.Descriptor(
    name="ImageOccurrence",
    full_name="grafeas.v1.ImageOccurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="fingerprint",
            full_name="grafeas.v1.ImageOccurrence.fingerprint",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="distance",
            full_name="grafeas.v1.ImageOccurrence.distance",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="layer_info",
            full_name="grafeas.v1.ImageOccurrence.layer_info",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="base_resource_url",
            full_name="grafeas.v1.ImageOccurrence.base_resource_url",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=247,
    serialized_end=394,
)

_IMAGENOTE.fields_by_name["fingerprint"].message_type = _FINGERPRINT
_IMAGEOCCURRENCE.fields_by_name["fingerprint"].message_type = _FINGERPRINT
_IMAGEOCCURRENCE.fields_by_name["layer_info"].message_type = _LAYER
DESCRIPTOR.message_types_by_name["Layer"] = _LAYER
DESCRIPTOR.message_types_by_name["Fingerprint"] = _FINGERPRINT
DESCRIPTOR.message_types_by_name["ImageNote"] = _IMAGENOTE
DESCRIPTOR.message_types_by_name["ImageOccurrence"] = _IMAGEOCCURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Layer = _reflection.GeneratedProtocolMessageType(
    "Layer",
    (_message.Message,),
    {
        "DESCRIPTOR": _LAYER,
        "__module__": "grafeas.grafeas_v1.proto.image_pb2",
        "__doc__": """Layer holds metadata specific to a layer of a Docker image.
  
  Attributes:
      directive:
          Required. The recovered Dockerfile directive used to construct
          this layer. See
          https://docs.docker.com/engine/reference/builder/ for more
          information.
      arguments:
          The recovered arguments to the Dockerfile directive.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Layer)
    },
)
_sym_db.RegisterMessage(Layer)

Fingerprint = _reflection.GeneratedProtocolMessageType(
    "Fingerprint",
    (_message.Message,),
    {
        "DESCRIPTOR": _FINGERPRINT,
        "__module__": "grafeas.grafeas_v1.proto.image_pb2",
        "__doc__": """A set of properties that uniquely identify a given Docker image.
  
  Attributes:
      v1_name:
          Required. The layer ID of the final layer in the Docker
          image’s v1 representation.
      v2_blob:
          Required. The ordered list of v2 blobs that represent a given
          image.
      v2_name:
          Output only. The name of the image’s v2 blobs computed via:
          [bottom] := v2_blob[bottom] [N] := sha256(v2_blob[N] + " " +
          v2_name[N+1]) Only the name of the final blob is kept.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Fingerprint)
    },
)
_sym_db.RegisterMessage(Fingerprint)

ImageNote = _reflection.GeneratedProtocolMessageType(
    "ImageNote",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMAGENOTE,
        "__module__": "grafeas.grafeas_v1.proto.image_pb2",
        "__doc__": """Basis describes the base image portion (Note) of the DockerImage
  relationship. Linked occurrences are derived from this or an
  equivalent image via: FROM <Basis.resource_url> Or an equivalent
  reference, e.g., a tag of the resource_url.
  
  Attributes:
      resource_url:
          Required. Immutable. The resource_url for the resource
          representing the basis of associated occurrence images.
      fingerprint:
          Required. Immutable. The fingerprint of the base image.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ImageNote)
    },
)
_sym_db.RegisterMessage(ImageNote)

ImageOccurrence = _reflection.GeneratedProtocolMessageType(
    "ImageOccurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _IMAGEOCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.image_pb2",
        "__doc__": """Details of the derived image portion of the DockerImage relationship.
  This image would be produced from a Dockerfile with FROM
  <DockerImage.Basis in attached Note>.
  
  Attributes:
      fingerprint:
          Required. The fingerprint of the derived image.
      distance:
          Output only. The number of layers by which this image differs
          from the associated image basis.
      layer_info:
          This contains layer-specific metadata, if populated it has
          length “distance” and is ordered with [distance] being the
          layer immediately following the base image and [1] being the
          final layer.
      base_resource_url:
          Output only. This contains the base image URL for the derived
          image occurrence.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ImageOccurrence)
    },
)
_sym_db.RegisterMessage(ImageOccurrence)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/build.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grafeas.grafeas_v1.proto import (
    provenance_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_provenance__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/build.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n$grafeas/grafeas_v1/proto/build.proto\x12\ngrafeas.v1\x1a)grafeas/grafeas_v1/proto/provenance.proto"$\n\tBuildNote\x12\x17\n\x0f\x62uilder_version\x18\x01 \x01(\t"\\\n\x0f\x42uildOccurrence\x12/\n\nprovenance\x18\x01 \x01(\x0b\x32\x1b.grafeas.v1.BuildProvenance\x12\x18\n\x10provenance_bytes\x18\x02 \x01(\tB_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
    dependencies=[grafeas_dot_grafeas__v1_dot_proto_dot_provenance__pb2.DESCRIPTOR,],
)


_BUILDNOTE = _descriptor.Descriptor(
    name="BuildNote",
    full_name="grafeas.v1.BuildNote",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="builder_version",
            full_name="grafeas.v1.BuildNote.builder_version",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=95,
    serialized_end=131,
)


_BUILDOCCURRENCE = _descriptor.Descriptor(
    name="BuildOccurrence",
    full_name="grafeas.v1.BuildOccurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="provenance",
            full_name="grafeas.v1.BuildOccurrence.provenance",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="provenance_bytes",
            full_name="grafeas.v1.BuildOccurrence.provenance_bytes",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=133,
    serialized_end=225,
)

_BUILDOCCURRENCE.fields_by_name[
    "provenance"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_provenance__pb2._BUILDPROVENANCE
DESCRIPTOR.message_types_by_name["BuildNote"] = _BUILDNOTE
DESCRIPTOR.message_types_by_name["BuildOccurrence"] = _BUILDOCCURRENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuildNote = _reflection.GeneratedProtocolMessageType(
    "BuildNote",
    (_message.Message,),
    {
        "DESCRIPTOR": _BUILDNOTE,
        "__module__": "grafeas.grafeas_v1.proto.build_pb2",
        "__doc__": """Note holding the version of the provider’s builder and the signature
  of the provenance message in the build details occurrence.
  
  Attributes:
      builder_version:
          Required. Immutable. Version of the builder which produced
          this build.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BuildNote)
    },
)
_sym_db.RegisterMessage(BuildNote)

BuildOccurrence = _reflection.GeneratedProtocolMessageType(
    "BuildOccurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _BUILDOCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.build_pb2",
        "__doc__": """Details of a build occurrence.
  
  Attributes:
      provenance:
          Required. The actual provenance for the build.
      provenance_bytes:
          Serialized JSON representation of the provenance, used in
          generating the build signature in the corresponding build
          note. After verifying the signature, ``provenance_bytes`` can
          be unmarshalled and compared to the provenance to confirm that
          it is unchanged. A base64-encoded string representation of the
          provenance bytes is used for the signature in order to
          interoperate with openssl which expects this format for
          signature verification.  The serialized form is captured both
          to avoid ambiguity in how the provenance is marshalled to json
          as well to prevent incompatibilities with future changes.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BuildOccurrence)
    },
)
_sym_db.RegisterMessage(BuildOccurrence)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Accesses the grafeas.v1 Grafeas API."""

import functools
import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.gapic_v1.routing_header
import google.api_core.grpc_helpers
import google.api_core.page_iterator
import google.api_core.path_template
import grpc

from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2
from grafeas.grafeas_v1.gapic import enums
from grafeas.grafeas_v1.gapic import grafeas_client_config
from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
from grafeas.grafeas_v1.proto import grafeas_pb2
from grafeas.grafeas_v1.proto import grafeas_pb2_grpc


_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("grafeas",).version


class GrafeasClient(object):
    """
    `Grafeas <https://grafeas.io>`__ API.

    Retrieves analysis results of Cloud components such as Docker container
    images.

    Analysis results are stored as a series of occurrences. An
    ``Occurrence`` contains information about a specific analysis instance
    on a resource. An occurrence refers to a ``Note``. A note contains
    details describing the analysis and is generally stored in a separate
    project, called a ``Provider``. Multiple occurrences can refer to the
    same note.

    For example, an SSL vulnerability could affect multiple images. In this
    case, there would be one note for the vulnerability and an occurrence
    for each image with the vulnerability referring to that note.
    """

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = "grafeas.v1.Grafeas"

    @classmethod
    def note_path(cls, project, note):
        """Return a fully-qualified note string."""
        return google.api_core.path_template.expand(
            "projects/{project}/notes/{note}", project=project, note=note,
        )

    @classmethod
    def occurrence_path(cls, project, occurrence):
        """Return a fully-qualified occurrence string."""
        return google.api_core.path_template.expand(
            "projects/{project}/occurrences/{occurrence}",
            project=project,
            occurrence=occurrence,
        )

    @classmethod
    def project_path(cls, project):
        """Return a fully-qualified project string."""
        return google.api_core.path_template.expand(
            "projects/{project}", project=project,
        )

    def __init__(self, transport, client_config=None, client_info=None):
        """Constructor.

        Args:
            transport (~.GrafeasGrpcTransport): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.

            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config is not None:
            warnings.warn(
                "The `client_config` argument is deprecated.",
                PendingDeprecationWarning,
                stacklevel=2,
            )
        else:
            client_config = grafeas_client_config.config

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        self.transport = transport

        if client_info is None:
            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
                gapic_version=_GAPIC_LIBRARY_VERSION,
            )
        else:
            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config["interfaces"][self._INTERFACE_NAME],
        )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def get_occurrence(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets the specified occurrence.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.occurrence_path('[PROJECT]', '[OCCURRENCE]')
            >>>
            >>> response = client.get_occurrence(name)

        Args:
            name (str): The name of the occurrence in the form of
                ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Occurrence` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_occurrence" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_occurrence"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_occurrence,
                default_retry=self._method_configs["GetOccurrence"].retry,
                default_timeout=self._method_configs["GetOccurrence"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.GetOccurrenceRequest(name=name,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_occurrence"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_occurrences(
        self,
        parent,
        filter_=None,
        page_size=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists occurrences for the specified project.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_occurrences(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_occurrences(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): The name of the project to list occurrences for in the form of
                ``projects/[PROJECT_ID]``.
            filter_ (str): The filter expression.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~grafeas.grafeas_v1.types.Occurrence` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_occurrences" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_occurrences"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_occurrences,
                default_retry=self._method_configs["ListOccurrences"].retry,
                default_timeout=self._method_configs["ListOccurrences"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.ListOccurrencesRequest(
            parent=parent, filter=filter_, page_size=page_size,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_occurrences"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="occurrences",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def delete_occurrence(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes the specified occurrence. For example, use this method to delete an
        occurrence when the occurrence is no longer applicable for the given
        resource.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.occurrence_path('[PROJECT]', '[OCCURRENCE]')
            >>>
            >>> client.delete_occurrence(name)

        Args:
            name (str): The name of the occurrence in the form of
                ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_occurrence" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_occurrence"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_occurrence,
                default_retry=self._method_configs["DeleteOccurrence"].retry,
                default_timeout=self._method_configs["DeleteOccurrence"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.DeleteOccurrenceRequest(name=name,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_occurrence"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def create_occurrence(
        self,
        parent,
        occurrence,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates a new occurrence.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize `occurrence`:
            >>> occurrence = {}
            >>>
            >>> response = client.create_occurrence(parent, occurrence)

        Args:
            parent (str): The name of the project in the form of ``projects/[PROJECT_ID]``,
                under which the occurrence is to be created.
            occurrence (Union[dict, ~grafeas.grafeas_v1.types.Occurrence]): The occurrence to create.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Occurrence`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Occurrence` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_occurrence" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_occurrence"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_occurrence,
                default_retry=self._method_configs["CreateOccurrence"].retry,
                default_timeout=self._method_configs["CreateOccurrence"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.CreateOccurrenceRequest(
            parent=parent, occurrence=occurrence,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_occurrence"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def batch_create_occurrences(
        self,
        parent,
        occurrences,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates new occurrences in batch.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize `occurrences`:
            >>> occurrences = []
            >>>
            >>> response = client.batch_create_occurrences(parent, occurrences)

        Args:
            parent (str): The name of the project in the form of ``projects/[PROJECT_ID]``,
                under which the occurrences are to be created.
            occurrences (list[Union[dict, ~grafeas.grafeas_v1.types.Occurrence]]): The occurrences to create. Max allowed length is 1000.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Occurrence`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.BatchCreateOccurrencesResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_create_occurrences" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_create_occurrences"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_create_occurrences,
                default_retry=self._method_configs["BatchCreateOccurrences"].retry,
                default_timeout=self._method_configs["BatchCreateOccurrences"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.BatchCreateOccurrencesRequest(
            parent=parent, occurrences=occurrences,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["batch_create_occurrences"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_occurrence(
        self,
        name,
        occurrence,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates the specified occurrence.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.occurrence_path('[PROJECT]', '[OCCURRENCE]')
            >>>
            >>> # TODO: Initialize `occurrence`:
            >>> occurrence = {}
            >>>
            >>> response = client.update_occurrence(name, occurrence)

        Args:
            name (str): The name of the occurrence in the form of
                ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
            occurrence (Union[dict, ~grafeas.grafeas_v1.types.Occurrence]): The updated occurrence.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Occurrence`
            update_mask (Union[dict, ~grafeas.grafeas_v1.types.FieldMask]): The fields to update.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Occurrence` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_occurrence" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_occurrence"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_occurrence,
                default_retry=self._method_configs["UpdateOccurrence"].retry,
                default_timeout=self._method_configs["UpdateOccurrence"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.UpdateOccurrenceRequest(
            name=name, occurrence=occurrence, update_mask=update_mask,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_occurrence"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def get_occurrence_note(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets the note attached to the specified occurrence. Consumer projects can
        use this method to get a note that belongs to a provider project.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.occurrence_path('[PROJECT]', '[OCCURRENCE]')
            >>>
            >>> response = client.get_occurrence_note(name)

        Args:
            name (str): The name of the occurrence in the form of
                ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Note` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_occurrence_note" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_occurrence_note"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_occurrence_note,
                default_retry=self._method_configs["GetOccurrenceNote"].retry,
                default_timeout=self._method_configs["GetOccurrenceNote"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.GetOccurrenceNoteRequest(name=name,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_occurrence_note"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def get_note(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Gets the specified note.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.note_path('[PROJECT]', '[NOTE]')
            >>>
            >>> response = client.get_note(name)

        Args:
            name (str): The name of the note in the form of
                ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Note` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "get_note" not in self._inner_api_calls:
            self._inner_api_calls[
                "get_note"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.get_note,
                default_retry=self._method_configs["GetNote"].retry,
                default_timeout=self._method_configs["GetNote"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.GetNoteRequest(name=name,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["get_note"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_notes(
        self,
        parent,
        filter_=None,
        page_size=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists notes for the specified project.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_notes(parent):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_notes(parent).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            parent (str): The name of the project to list notes for in the form of
                ``projects/[PROJECT_ID]``.
            filter_ (str): The filter expression.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~grafeas.grafeas_v1.types.Note` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_notes" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_notes"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_notes,
                default_retry=self._method_configs["ListNotes"].retry,
                default_timeout=self._method_configs["ListNotes"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.ListNotesRequest(
            parent=parent, filter=filter_, page_size=page_size,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_notes"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="notes",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator

    def delete_note(
        self,
        name,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Deletes the specified note.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.note_path('[PROJECT]', '[NOTE]')
            >>>
            >>> client.delete_note(name)

        Args:
            name (str): The name of the note in the form of
                ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "delete_note" not in self._inner_api_calls:
            self._inner_api_calls[
                "delete_note"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.delete_note,
                default_retry=self._method_configs["DeleteNote"].retry,
                default_timeout=self._method_configs["DeleteNote"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.DeleteNoteRequest(name=name,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        self._inner_api_calls["delete_note"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def create_note(
        self,
        parent,
        note_id,
        note,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates a new note.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize `note_id`:
            >>> note_id = ''
            >>>
            >>> # TODO: Initialize `note`:
            >>> note = {}
            >>>
            >>> response = client.create_note(parent, note_id, note)

        Args:
            parent (str): The name of the project in the form of ``projects/[PROJECT_ID]``,
                under which the note is to be created.
            note_id (str): The ID to use for this note.
            note (Union[dict, ~grafeas.grafeas_v1.types.Note]): The note to create.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Note`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Note` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "create_note" not in self._inner_api_calls:
            self._inner_api_calls[
                "create_note"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.create_note,
                default_retry=self._method_configs["CreateNote"].retry,
                default_timeout=self._method_configs["CreateNote"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.CreateNoteRequest(
            parent=parent, note_id=note_id, note=note,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["create_note"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def batch_create_notes(
        self,
        parent,
        notes,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Creates new notes in batch.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize `notes`:
            >>> notes = {}
            >>>
            >>> response = client.batch_create_notes(parent, notes)

        Args:
            parent (str): The name of the project in the form of ``projects/[PROJECT_ID]``,
                under which the notes are to be created.
            notes (dict[str -> Union[dict, ~grafeas.grafeas_v1.types.Note]]): The notes to create. Max allowed length is 1000.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Note`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.BatchCreateNotesResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "batch_create_notes" not in self._inner_api_calls:
            self._inner_api_calls[
                "batch_create_notes"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.batch_create_notes,
                default_retry=self._method_configs["BatchCreateNotes"].retry,
                default_timeout=self._method_configs["BatchCreateNotes"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.BatchCreateNotesRequest(parent=parent, notes=notes,)
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("parent", parent)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["batch_create_notes"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def update_note(
        self,
        name,
        note,
        update_mask=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Updates the specified note.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.note_path('[PROJECT]', '[NOTE]')
            >>>
            >>> # TODO: Initialize `note`:
            >>> note = {}
            >>>
            >>> response = client.update_note(name, note)

        Args:
            name (str): The name of the note in the form of
                ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
            note (Union[dict, ~grafeas.grafeas_v1.types.Note]): The updated note.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.Note`
            update_mask (Union[dict, ~grafeas.grafeas_v1.types.FieldMask]): The fields to update.

                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~grafeas.grafeas_v1.types.FieldMask`
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~grafeas.grafeas_v1.types.Note` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "update_note" not in self._inner_api_calls:
            self._inner_api_calls[
                "update_note"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.update_note,
                default_retry=self._method_configs["UpdateNote"].retry,
                default_timeout=self._method_configs["UpdateNote"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.UpdateNoteRequest(
            name=name, note=note, update_mask=update_mask,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        return self._inner_api_calls["update_note"](
            request, retry=retry, timeout=timeout, metadata=metadata
        )

    def list_note_occurrences(
        self,
        name,
        filter_=None,
        page_size=None,
        retry=google.api_core.gapic_v1.method.DEFAULT,
        timeout=google.api_core.gapic_v1.method.DEFAULT,
        metadata=None,
    ):
        """
        Lists occurrences referencing the specified note. Provider projects can use
        this method to get all occurrences across consumer projects referencing the
        specified note.

        Example:
            >>> from grafeas import grafeas_v1
            >>> from grafeas.grafeas_v1.gapic.transports import grafeas_grpc_transport
            >>> 
            >>> address = "[SERVICE_ADDRESS]"
            >>> scopes = ("[SCOPE]")
            >>> transport = grafeas_grpc_transport.GrafeasGrpcTransport(address, scopes)
            >>> client = grafeas_v1.GrafeasClient(transport)
            >>>
            >>> name = client.note_path('[PROJECT]', '[NOTE]')
            >>>
            >>> # Iterate over all results
            >>> for element in client.list_note_occurrences(name):
            ...     # process element
            ...     pass
            >>>
            >>>
            >>> # Alternatively:
            >>>
            >>> # Iterate over results one page at a time
            >>> for page in client.list_note_occurrences(name).pages:
            ...     for element in page:
            ...         # process element
            ...         pass

        Args:
            name (str): The name of the note to list occurrences for in the form of
                ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
            filter_ (str): The filter expression.
            page_size (int): The maximum number of resources contained in the
                underlying API response. If page streaming is performed per-
                resource, this parameter does not affect the return value. If page
                streaming is performed per-page, this determines the maximum number
                of resources in a page.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will
                be retried using a default configuration.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.api_core.page_iterator.PageIterator` instance.
            An iterable of :class:`~grafeas.grafeas_v1.types.Occurrence` instances.
            You can also iterate over the pages of the response
            using its `pages` property.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if "list_note_occurrences" not in self._inner_api_calls:
            self._inner_api_calls[
                "list_note_occurrences"
            ] = google.api_core.gapic_v1.method.wrap_method(
                self.transport.list_note_occurrences,
                default_retry=self._method_configs["ListNoteOccurrences"].retry,
                default_timeout=self._method_configs["ListNoteOccurrences"].timeout,
                client_info=self._client_info,
            )

        request = grafeas_pb2.ListNoteOccurrencesRequest(
            name=name, filter=filter_, page_size=page_size,
        )
        if metadata is None:
            metadata = []
        metadata = list(metadata)
        try:
            routing_header = [("name", name)]
        except AttributeError:
            pass
        else:
            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
                routing_header
            )
            metadata.append(routing_metadata)

        iterator = google.api_core.page_iterator.GRPCIterator(
            client=None,
            method=functools.partial(
                self._inner_api_calls["list_note_occurrences"],
                retry=retry,
                timeout=timeout,
                metadata=metadata,
            ),
            request=request,
            items_field="occurrences",
            request_token_field="page_token",
            response_token_field="next_page_token",
        )
        return iterator
